Windu Agent
--------------

.. image:: http://codefoco.zapto.org:8085/buildStatus/icon?job=wagent
.. image:: https://img.shields.io/pypi/v/wagent.svg

**DISCLAIMER**

**This is a personal project I started to learn new stuff and for fun ☺️**

**This has no intention to be a product or compete with any other product**


Windu agent is responsible to receive and send message to the instant messaging service.

Example:

``agent = WinduAgent.WinduAgent('00000', 'Nick',  WinduAgent.WinduAgent.AUTOREPLY_READ, 'pw')``

``agent.sendMessage ('1111', u'Hello 😅')``